{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
    <p class="bg-blue-50 border-blue-200 mb-8 p-3 rounded-default text-blue-500 text-sm dark:bg-blue-500/20 dark:border-blue-500/10">
        {% translate "After you've created a user, you’ll be able to edit more user options." %}
        <p>
{% endblock %}
